import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { useState } from 'react';
import { useDispatch } from 'react-redux';
import { ActionMenu, Button, Box } from "@primer/react";
import { ChevronRightIcon, XIcon, ChevronUpIcon, ChevronDownIcon, SquareIcon } from "@primer/octicons-react";
import { DLA_CELL_HEADER_CLASS } from './base/CellSidebarWidget';
import { notebookActions, selectActiveCell } from '../../NotebookState';
import CellMetadataEditor from '../metadata/CellMetadataEditor';
export const CellSidebarDefault = (props) => {
    const [visible, setVisible] = useState(false);
    const { notebookId, nbgrader } = props;
    const dispatch = useDispatch();
    const activeCell = selectActiveCell(notebookId);
    const layout = (activeCell?.layout);
    if (layout) {
        const cellWidget = layout.widgets[0];
        if (!visible && (cellWidget?.node.id === props.cellId)) {
            setVisible(true);
        }
        if (visible && (cellWidget?.node.id !== props.cellId)) {
            setVisible(false);
        }
    }
    if (!visible) {
        return _jsx("div", {});
    }
    return (activeCell ?
        _jsxs(Box, { className: DLA_CELL_HEADER_CLASS, sx: {
                '& p': {
                    marginBottom: '0 !important',
                }
            }, children: [_jsx("span", { style: { display: "flex" }, children: _jsx(Button, { leadingIcon: ChevronRightIcon, variant: "invisible", size: "small", onClick: (e) => {
                            e.preventDefault();
                            dispatch(notebookActions.run.started(notebookId));
                        }, children: "Run" }) }), _jsx("span", { style: { display: "flex" }, children: _jsx(Button, { leadingIcon: ChevronUpIcon, variant: "invisible", size: "small", onClick: (e) => {
                            e.preventDefault();
                            dispatch(notebookActions.insertAbove.started({ uid: notebookId, cellType: "code" }));
                        }, children: "Code" }) }), _jsx("span", { style: { display: "flex" }, children: _jsx(Button, { leadingIcon: ChevronUpIcon, variant: "invisible", size: "small", onClick: (e) => {
                            e.preventDefault();
                            dispatch(notebookActions.insertAbove.started({ uid: notebookId, cellType: "markdown" }));
                        }, children: "Markdown" }) }), _jsx("span", { style: { display: "flex" }, children: activeCell.model.type === "code" ?
                        _jsx(Button, { leadingIcon: SquareIcon, variant: "invisible", size: "small", onClick: (e) => {
                                e.preventDefault();
                                dispatch(notebookActions.changeCellType.started({ uid: notebookId, cellType: "markdown" }));
                            }, children: "To Mardown" })
                        :
                            _jsx(Button, { leadingIcon: SquareIcon, variant: "invisible", size: "small", onClick: (e) => {
                                    e.preventDefault();
                                    dispatch(notebookActions.changeCellType.started({ uid: notebookId, cellType: "code" }));
                                }, children: "To Code" }) }), _jsx("span", { style: { display: "flex" }, children: _jsx(Button, { leadingIcon: ChevronDownIcon, variant: "invisible", size: "small", onClick: (e) => {
                            e.preventDefault();
                            dispatch(notebookActions.insertBelow.started({ uid: notebookId, cellType: "markdown" }));
                        }, children: "Markdown" }) }), _jsx("span", { style: { display: "flex" }, children: _jsx(Button, { leadingIcon: ChevronDownIcon, variant: "invisible", size: "small", onClick: (e) => {
                            e.preventDefault();
                            dispatch(notebookActions.insertBelow.started({ uid: notebookId, cellType: "code" }));
                        }, children: "Code" }) }), _jsx("span", { style: { display: "flex" }, children: _jsx(Button, { leadingIcon: XIcon, variant: "invisible", size: "small", onClick: (e) => {
                            e.preventDefault();
                            dispatch(notebookActions.delete.started(notebookId));
                        }, children: "Delete" }) }), nbgrader &&
                    _jsx(ActionMenu, { children: _jsx(CellMetadataEditor, { notebookId: notebookId, cell: activeCell, nbgrader: nbgrader }) })] })
        :
            _jsx(_Fragment, {}));
};
export default CellSidebarDefault;
//# sourceMappingURL=CellSidebarDefault.js.map