import React from "react";
import { ServiceManager, ServerConnection, KernelManager } from '@jupyterlab/services';
import Kernel from './services/kernel/Kernel';
/**
 * The type for the Jupyter context.
 */
export declare type JupyterContextType = {
    lite: boolean;
    serverSettings: ServerConnection.ISettings;
    serviceManager?: ServiceManager;
    kernelManager?: KernelManager;
    defaultKernel?: Kernel;
    startDefaultKernel: boolean;
    variant: string;
    setVariant: (value: string) => void;
    baseUrl: string;
    wsUrl: string;
    injectableStore: any;
};
/**
 * The instance for the Jupyter context.
 */
export declare const JupyterContext: React.Context<JupyterContextType | undefined>;
export declare const useJupyter: () => JupyterContextType;
/**
 * The type for the Jupyter context consumer.
 */
export declare const JupyterContextConsumer: React.Consumer<JupyterContextType | undefined>;
/**
 * Utiliy method to ensure the Jupyter context is authenticated
 * with the Jupyter server.
 */
export declare const ensureJupyterAuth: (serverSettings: ServerConnection.ISettings) => Promise<boolean>;
/**
 * The Jupyter context provider.
 */
export declare const JupyterContextProvider: React.FC<{
    children: React.ReactNode;
    lite: boolean;
    startDefaultKernel: boolean;
    defaultKernelName: string;
    variant: string;
    baseUrl: string;
    wsUrl: string;
    injectableStore: any;
}>;
