import { ISettingRegistry } from '@jupyterlab/settingregistry';
import { MainAreaWidget, ICommandPalette } from '@jupyterlab/apputils';
import { ILauncher } from '@jupyterlab/launcher';
import { reactIcon } from '@jupyterlab/ui-components';
import { requestAPI } from './handler';
import { DatalayerWidget } from './widget';
import '../../../style/index.css';
/**
 * The command IDs used by the react-widget plugin.
 */
var CommandIDs;
(function (CommandIDs) {
    CommandIDs.create = 'create-jupyter-react-widget';
})(CommandIDs || (CommandIDs = {}));
/**
 * Initialization data for the @datalayer/jupyter-react extension.
 */
const plugin = {
    id: '@datalayer/jupyter-react:plugin',
    autoStart: true,
    requires: [ICommandPalette],
    optional: [ISettingRegistry, ILauncher],
    activate: (app, palette, settingRegistry, launcher) => {
        const { commands } = app;
        const command = CommandIDs.create;
        commands.addCommand(command, {
            caption: 'Show Jupyter React',
            label: 'Jupyter React',
            icon: (args) => reactIcon,
            execute: () => {
                const content = new DatalayerWidget();
                const widget = new MainAreaWidget({ content });
                widget.title.label = 'Jupyter React';
                widget.title.icon = reactIcon;
                app.shell.add(widget, 'main');
            }
        });
        const category = 'Jupyter React';
        palette.addItem({ command, category, args: { origin: 'from palette' } });
        if (launcher) {
            launcher.add({
                command
            });
        }
        console.log('JupyterLab extension @datalayer/jupyter-react is activated!');
        if (settingRegistry) {
            settingRegistry
                .load(plugin.id)
                .then(settings => {
                console.log('@datalayer/jupyter-react settings loaded:', settings.composite);
            })
                .catch(reason => {
                console.error('Failed to load settings for @datalayer/jupyter-react.', reason);
            });
        }
        requestAPI('get_example')
            .then(data => {
            console.log(data);
        })
            .catch(reason => {
            console.error(`The datalayer server extension appears to be missing.\n${reason}`);
        });
    }
};
export default plugin;
//# sourceMappingURL=index.js.map