import { SessionManager } from '@jupyterlab/services';
import { UUID } from '@lumino/coreutils';
export class Kernel {
    _kernelManager;
    _kernelName;
    _jupyterKernel;
    _session;
    _id;
    _info;
    constructor(props) {
        this._kernelManager = props.kernelManager;
        this._kernelName = props.kernelName;
        this._jupyterKernel = this.requestJupyterKernel(); // Request the effective Jupyter Kernel.
    }
    async requestJupyterKernel() {
        await this._kernelManager.ready;
        const sessionManager = new SessionManager({
            kernelManager: this._kernelManager,
            serverSettings: this._kernelManager.serverSettings,
            standby: 'never',
        });
        await sessionManager.ready;
        const randomName = UUID.uuid4() + ".ipynb";
        this._session = await sessionManager.startNew({
            path: randomName,
            name: randomName,
            type: 'notebook',
            kernel: {
                name: this._kernelName,
            },
        });
        this._info = await this._session.kernel.info;
        this._id = this._session.kernel.id;
        return this._session.kernel;
    }
    get id() {
        return this._id;
    }
    get info() {
        return this._info;
    }
    get session() {
        return this._session;
    }
    getJupyterKernel() {
        return this._jupyterKernel;
    }
    shutdown() {
        this._session.kernel?.shutdown();
        this.getJupyterKernel().then(k => k.dispose());
    }
}
export default Kernel;
//# sourceMappingURL=Kernel.js.map